#Introductory information

##General information 
Title: DIGGER dataset
Authors: Antoine Peris (Faculty of Architecture and the Build Environment, TU Delft), Willem Jan Faber (Koninklijke Bibliotheek)
Description: Information flows between the Dutch cities (1869-1994) extracted from Delpher database (https://www.delpher.nl/), the digital archive of historical newspapers of the Koninklijke Bibliotheek. 

Data paper: One century of information diffusion in the Netherlands derived from a massive digital archive of historical newspapers

##List of files 
cities_information.csv 			: geographical information on cities for which data has been collected
freq_count_corpus.txt 			: number of news items published by newspapers (per year/type)
freq_count_NER.csv 				: news flows between cities with ambiguous names and publication places of the newspapers (per year/type)
freq_count_STR.csv 				: news flows between cities with unambiguous names and publication places of the newspapers (per year/type)
np_metadata.csv 				: main information on the different newspapers titles included in the study
ppn_correspondance.txt 			: table to aggregate unique newspapers with multiple ppn code
thesaurus_cities.txt 			: table to aggregate unique cities that have different names (ex. 's-Gravenhage = Den Haag)

##Relationship between the files 

The column connecting the different files related to newspapers information is the 'ppn' column. It is a unique identifier corresponding to a newspaper. 
For information related to cities, the column is 'city'. 
In order to link this dataset with historical populations and geometries. The cities_information.csv has a "ams_code" column that corresponds to the amsterdam code as defined in https://www.gemeentegeschiedenis.nl/pagina/1/. 

#Methodological information 

##Method description for collecting or generating the data
The data was created by querying the catalogue of the Koninklijke Biliotheek via a SRU protocol (http://jsru.kb.nl/sru/sru?query=).

##Software
The data was collected with a python 3 program using the packages sys, requests, json, lxml, time, random, collections. 
Tables were produced with R (version 3.6.0) (tidyverse, qdap). Spatial data was obtained from http://nlgis.nl/, https://www.gemeentegeschiedenis.nl/ and https://www.geonames.org/. It was obtained and processed with geojsonsf, rvest, sf.

For freq_count_NER.csv, an extra operation was performed in order to verify whether the character strings in the news items were actual place names. This was apply only for ambiguous place names. The main cases were common family names (i.e. van de Beek), or names that are also words in the common language (Best, Huizen, etc.). We used the multiNER software (https://github.com/KBNLresearch/multiNER ), a NER set-up developed by the research department of the National Library of the Netherlands for the enrichment of several Dutch text corpora. This software is combining the outputs of 3 different NER packages in order to increase the accuracy of the recognition by using a certainty score.


##Quality-assurance procedures performed on the data 
Accuracy tests were performed in order to assess the quality of the data. 150 outcomes of the SRU protocol, including both string queries and string+NER queries were assed manually. The results of the recall and precision test are displayed in the data paper associated with this dataset. 

#Data specific information

The 'cities_information.csv' has the following fields:
------------------------------------------------------
city 			: city/place name (Dutch 'woonplaatsen' were used for the city names)
ams_code 		: amsterdam code of the municipality in which the city is located (see https://www.gemeentegeschiedenis.nl/)
geonameID 		: geonameID (see https://www.geonames.org/)
province 		: name of the province in which the city is located (https://www.geonames.org/)
adminCode1 		: administrative code of the province (see https://www.geonames.org/)
lon 			: longitude of the city (obtained form https://www.geonames.org/), ESPG:4326
lat  			: latitude of the city (obtained from https://www.geonames.org/), ESPG:4326

The 'freq_count_corpus.txt' has the following fields:
------------------------------------------------------
ppn 			: unique identifier  of the newspaper
year 			: publication year	
type 			: type of news item (article, advertisement, family announcement, caption of illustration) 
freq 			: number of news items

The 'freq_count_NER.csv' has the following fields:
------------------------------------------------------
ppn 			: unique identifier  of the newspaper
city 			: city mentioned
year 			: publication year
type 			: type of news item (article, advertisement, family announcement, caption of illustration) 
freq_str 		: number of news items (string matching method)
freq_ner 		: number of news items (after named entity recognition)

The 'freq_count_STR.csv' has the following fields:
------------------------------------------------------
ppn 			: unique identifier  of the newspaper
city 			: city mentioned
year 			: publication year
type 			: type of news item (article, advertisement, family announcement, caption of illustration) 
freq 			: number of news items (string matching method)

The 'np_metadata.csv' has the following fields:
------------------------------------------------------
PPN				: unique identifier  of the newspaper
TITLE			: name of the newspaper
PUB_PLACE		: publication place of the newspaper
SCOPE			: geographical scope (National or Local)
START			: first year in the database
END				: last year in the database

#Sharing and Access information 
This work is licensed under a Creative Commons CC-BY 4.0 https://creativecommons.org/licenses/by/4.0/ 